summaryrefslogtreecommitdiffstats
path: root/sys/amd64
diff options
context:
space:
mode:
authorjeff <jeff@FreeBSD.org>2002-10-12 05:32:24 +0000
committerjeff <jeff@FreeBSD.org>2002-10-12 05:32:24 +0000
commitef4d4e378e012b3efd909e2abc5c1ddcf38faee7 (patch)
tree69991942d3c51153d9210031e7380779edf05aaf /sys/amd64
parentcf318b70e5aa88b25cdf3d47eacce75c5aa889db (diff)
downloadFreeBSD-src-ef4d4e378e012b3efd909e2abc5c1ddcf38faee7.zip
FreeBSD-src-ef4d4e378e012b3efd909e2abc5c1ddcf38faee7.tar.gz
- Create a new scheduler api that is defined in sys/sched.h
- Begin moving scheduler specific functionality into sched_4bsd.c - Replace direct manipulation of scheduler data with hooks provided by the new api. - Remove KSE specific state modifications and single runq assumptions from kern_switch.c Reviewed by: -arch
Diffstat (limited to 'sys/amd64')
-rw-r--r--sys/amd64/amd64/machdep.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/sys/amd64/amd64/machdep.c b/sys/amd64/amd64/machdep.c
index b414eaf..380ddee 100644
--- a/sys/amd64/amd64/machdep.c
+++ b/sys/amd64/amd64/machdep.c
@@ -69,6 +69,7 @@
#include <sys/reboot.h>
#include <sys/callout.h>
#include <sys/msgbuf.h>
+#include <sys/sched.h>
#include <sys/sysent.h>
#include <sys/sysctl.h>
#include <sys/ucontext.h>
@@ -818,7 +819,7 @@ SYSCTL_INT(_machdep, OID_AUTO, cpu_idle_hlt, CTLFLAG_RW,
/*
* Note that we have to be careful here to avoid a race between checking
* kserunnable() and actually halting. If we don't do this, we may waste
* the time between calling hlt and the next interrupt even though there
* is a runnable process.
*/
@@ -827,7 +828,7 @@ cpu_idle(void)
{
if (cpu_idle_hlt) {
disable_intr();
- if (kserunnable()) {
+ if (sched_runnable()) {
enable_intr();
} else {
/*
@@ -818,7 +819,7 @@ SYSCTL_INT(_machdep, OID_AUTO, cpu_idle_hlt, CTLFLAG_RW,
/*
* Note that we have to be careful here to avoid a race between checking
- * kserunnable() and actually halting. If we don't do this, we may waste
+ * sched_runnable() and actually halting. If we don't do this, we may waste
* the time between calling hlt and the next interrupt even though there
* is a runnable process.
OpenPOWER on IntegriCloud